==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/he.js <==
OC.L10N.register(
    "text",
    {
    "Nextcloud Text" : "טקסט Nextcloud",
    "text document" : "מסמך טקסט",
    "Readme" : "הסבר",
    "Text" : "טקסט",
    "📝 Collaborative document editing" : "📝 עריכת מסמכים שיתופית",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 עריכת מסמכים שיתופית!**\n\n- **📝 כתיבה ממוקדת:** בלי הפרעות, רק כלי העיצוב הנחוצים.\n- **🙋 לעבוד ביחד:** שיתוף פעולה עם חברים ועמיתים לעבודה, בין אם הם משתמשים ב־Nextcloud או לא!\n- **💾 תקן פתוח:** הקבצים נשמרים בתור [Markdown](https://en.wikipedia.org/wiki/Markdown), כך שניתן לערוך אותם בכל יישומון טקסט אחר בנוסף.\n- **✊ יסודות יציבים:** אנו משתמשים ב־[🐈 tiptap](https://tiptap.scrumpy.io) שמבוסס על [🦉 ProseMirror](https://prosemirror.net) – תודה ענקית להם!",
    "Use current version" : "להשתמש בגרסה הנוכחית",
    "Use the saved version" : "להשתמש בגרסה השמורה",
    "The document has been changed outside of the editor. The changes cannot be applied." : "המסמך נערך מחוץ לעורך. לא ניתן להחיל את השינויים.",
    "File could not be loaded. Please check your internet connection." : "לא ניתן לטעון את הקובץ. נא לבדוק את מצב החיבור שלך לאינטרנט.",
    "Retry" : "ניסיון חוזר",
    "Last saved {lastSaved}" : "שמירה אחרונה: {lastSaved}",
    "Unpushed changes" : "שינויים שלא נדחפו",
    "Unsaved changes" : "שינויים שלא נשמרו",
    "Enter your name so other users can see who is editing" : "נא למלא את שמך כדי שמשתמשים אחרים יוכלו לראות מי עורך",
    "Edit guest name" : "עריכת שם אורח",
    "Save guest name" : "שמירת שם אורח",
    "Insert image" : "הוספת תמונה",
    "Add link" : "הוספת קישור",
    "_and %n other editor_::_and %n other editors_" : ["ועורך (%n) נוסף","ו־%n עורכים נוספים","ו־%n עורכים נוספים","ו־%n עורכים נוספים"],
    "Show image" : "הצגת תמונה",
    "Show file" : "הצגת קובץ",
    "Show rich workspaces" : "הצגת סביבות עבודה עשירות",
    "Add notes, lists or links …" : "ניתן להוסיף הערות, רשימות או קישורים…",
    "New text document" : "מסמך טקסט חדש",
    "Edit" : "עריכה",
    "Undo" : "ביטול",
    "Redo" : "שחזור",
    "Bold" : "מודגש",
    "Italic" : "נטוי",
    "Strikethrough" : "קו חוצה",
    "Paragraph" : "פסקה",
    "Headings" : "כותרות",
    "Heading 1" : "כותרת 1",
    "Heading 2" : "כותרת 2",
    "Heading 3" : "כותרת 3",
    "Heading 4" : "כותרת 4",
    "Heading 5" : "כותרת 5",
    "Heading 6" : "כותרת 6",
    "Unordered list" : "רשימה בלתי ממוינת",
    "Ordered list" : "רשימה ממוינת",
    "ToDo list" : "רשימת מטלות",
    "Blockquote" : "מקטע ציטוט",
    "Code block" : "מקטע קוד",
    "Network connection error: Could not connect to the document" : "שגיאה בחיבור לרשת: לא ניתן להתחבר למסמך",
    "Last save {lastSave}" : "שמירה אחרונה: {lastSaved}",
    "New text document.md" : "מסמך טקסט חדש.md"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-19.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/he.js <==
OC.L10N.register(
    "text",
    {
    "Nextcloud Text" : "טקסט Nextcloud",
    "text document" : "מסמך טקסט",
    "Readme" : "הסבר",
    "Text" : "טקסט",
    "📝 Collaborative document editing" : "📝 עריכת מסמכים שיתופית",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 עריכת מסמכים שיתופית!**\n\n- **📝 כתיבה ממוקדת:** בלי הפרעות, רק כלי העיצוב הנחוצים.\n- **🙋 לעבוד ביחד:** שיתוף פעולה עם חברים ועמיתים לעבודה, בין אם הם משתמשים ב־Nextcloud או לא!\n- **💾 תקן פתוח:** הקבצים נשמרים בתור [Markdown](https://en.wikipedia.org/wiki/Markdown), כך שניתן לערוך אותם בכל יישומון טקסט אחר בנוסף.\n- **✊ יסודות יציבים:** אנו משתמשים ב־[🐈 tiptap](https://tiptap.scrumpy.io) שמבוסס על [🦉 ProseMirror](https://prosemirror.net) – תודה ענקית להם!",
    "Use current version" : "להשתמש בגרסה הנוכחית",
    "Use the saved version" : "להשתמש בגרסה השמורה",
    "The document has been changed outside of the editor. The changes cannot be applied." : "המסמך נערך מחוץ לעורך. לא ניתן להחיל את השינויים.",
    "File could not be loaded. Please check your internet connection." : "לא ניתן לטעון את הקובץ. נא לבדוק את מצב החיבור שלך לאינטרנט.",
    "Retry" : "ניסיון חוזר",
    "Last saved {lastSaved}" : "שמירה אחרונה: {lastSaved}",
    "Unpushed changes" : "שינויים שלא נדחפו",
    "Unsaved changes" : "שינויים שלא נשמרו",
    "Enter your name so other users can see who is editing" : "נא למלא את שמך כדי שמשתמשים אחרים יוכלו לראות מי עורך",
    "Edit guest name" : "עריכת שם אורח",
    "Save guest name" : "שמירת שם אורח",
    "Insert image" : "הוספת תמונה",
    "Insert an image" : "הוספת תמונה",
    "Link file" : "קישור לקובץ",
    "Select file to link to" : "לבחור קובץ לקשר אליו",
    "_and %n other editor_::_and %n other editors_" : ["ועורך (%n) נוסף","ו־%n עורכים נוספים","ו־%n עורכים נוספים","ו־%n עורכים נוספים"],
    "Show rich workspaces" : "הצגת סביבות עבודה עשירות",
    "Add notes, lists or links …" : "ניתן להוסיף הערות, רשימות או קישורים…",
    "New text document" : "מסמך טקסט חדש",
    "Edit" : "עריכה",
    "Undo" : "ביטול",
    "Redo" : "שחזור",
    "Bold" : "מודגש",
    "Italic" : "נטוי",
    "Strikethrough" : "קו חוצה",
    "Headings" : "כותרות",
    "Heading 1" : "כותרת 1",
    "Heading 2" : "כותרת 2",
    "Heading 3" : "כותרת 3",
    "Heading 4" : "כותרת 4",
    "Heading 5" : "כותרת 5",
    "Heading 6" : "כותרת 6",
    "Unordered list" : "רשימה בלתי ממוינת",
    "Ordered list" : "רשימה ממוינת",
    "ToDo list" : "רשימת מטלות",
    "Blockquote" : "מקטע ציטוט",
    "Code block" : "מקטע קוד",
    "Network connection error: Could not connect to the document" : "שגיאה בחיבור לרשת: לא ניתן להתחבר למסמך",
    "Last save {lastSave}" : "שמירה אחרונה: {lastSaved}",
    "Add link" : "הוספת קישור",
    "Show image" : "הצגת תמונה",
    "Show file" : "הצגת קובץ",
    "Paragraph" : "פסקה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
